import type { Route } from "next";
import {
  BarChart,
  BarChart4,
  Bolt,
  BookA,
  BookText,
  Building,
  CircleUser,
  Cloudy,
  CreditCard,
  FlaskConical,
  FlaskRound,
  GitCommitHorizontal,
  HelpCircle,
  Key,
  Layers,
  LayoutDashboard,
  LucideIcon,
  Ruler,
  Settings,
  Sparkle,
  Sparkles,
  Sprout,
  Star,
  Users,
  Wrench,
} from "lucide-react";
import { MainNavItem, SidebarNavItem } from "./types/nav";

export type NavItem = {
  href: Route;
  title: string;
  badge?: string;
  icon?: LucideIcon;
};

export type GroupedNavItems = {
  group: string;
  items: NavItem[];
};

export const sideNavItems: GroupedNavItems[] = [
  {
    group: "EVALUATION",
    items: [
      {
        href: "/new-analysis",
        title: "Create New Analysis",
        icon: FlaskConical,
      },
      {
        href: "/analysis",
        title: "Analysis",
        icon: FlaskRound,
      },
    ],
  },
  {
    group: "COURSE",
    items: [
      {
        href: "/course",
        title: "Your Course",
        // badge: "soon",
        icon: BookText,
      },
    ],
  },
  {
    group: "ADMIN",
    items: [
      {
        href: "/users",
        title: "Users",
        icon: Users,
      },
      {
        href: "/organization",
        title: "Organization",
        icon: Building,
      },
      {
        href: "/account",
        title: "Account",
        icon: CircleUser,
      },
      {
        href: "/preferences",
        title: "Preferences",
        icon: Bolt,
      },
      {
        href: "/configuration",
        title: "Configuration",
        icon: Wrench,
      },
      {
        href: "/api-communication",
        title: "Api Communication",
        icon: Cloudy,
      },
      {
        href: "/course-admin",
        title: "Course Admin",
        icon: BookA,
      },
    ],
  },

  {
    group: "ACCOUNT",
    items: [
      {
        href: "/change-password",
        title: "Change Password",
        icon: Key,
      },
    ],
  },
  {
    group: "EVALUATIONS",
    items: [
      {
        href: "/criteria",
        title: "Criteria",
        // badge: "soon",
        icon: Ruler,
      },
      {
        href: "/skill",
        title: "Skill",
        // badge: "soon",
        icon: Sparkles,
      },
      {
        href: "/evaluation",
        title: "Evaluation",
        // badge: "soon",
        icon: BarChart4,
      },
      {
        href: "/commit",
        title: "Commit",
        // badge: "soon",
        icon: GitCommitHorizontal,
      },
    ],
  },
];

export const siteConfig = {
  name: "Skilld Admin",
  description:
    "Empower your financial management with AI-driven insights, making tracking and optimizing your finances effortless.",
  github: "https://github.com/projectx-codehagen/Badget",
  twitter: "https://twitter.com/codehagen",
};

export const topNavItems = [
  {
    href: "/docs",
    title: "Documentation",
  },
  {
    href: "/support",
    title: "Support",
  },
] satisfies NavItem[];

interface DocsConfig {
  mainNav: MainNavItem[];
  sidebarNav: SidebarNavItem[];
}

export const docsConfig: DocsConfig = {
  mainNav: [
    {
      title: "Documentation",
      href: "/docs",
    },
    {
      title: "Components",
      href: "/docs/components/accordion",
    },
    {
      title: "Themes",
      href: "/themes",
    },
    {
      title: "Examples",
      href: "/examples",
    },
    {
      title: "Blocks",
      href: "/blocks",
    },
  ],
  sidebarNav: [
    {
      title: "Getting Started",
      items: [
        {
          title: "Introduction",
          href: "/docs",
          items: [],
        },
        {
          title: "Installation",
          href: "/docs/installation",
          items: [],
        },
        {
          title: "components.json",
          href: "/docs/components-json",
          items: [],
        },
        {
          title: "Theming",
          href: "/docs/theming",
          items: [],
        },
        {
          title: "Dark mode",
          href: "/docs/dark-mode",
          items: [],
        },
        {
          title: "CLI",
          href: "/docs/cli",
          items: [],
        },
        {
          title: "Typography",
          href: "/docs/components/typography",
          items: [],
        },
        {
          title: "Figma",
          href: "/docs/figma",
          items: [],
        },
        {
          title: "Changelog",
          href: "/docs/changelog",
          items: [],
        },
      ],
    },
    {
      title: "Components",
      items: [
        {
          title: "Accordion",
          href: "/docs/components/accordion",
          items: [],
        },
        {
          title: "Alert",
          href: "/docs/components/alert",
          items: [],
        },
        {
          title: "Alert Dialog",
          href: "/docs/components/alert-dialog",
          items: [],
        },
        {
          title: "Aspect Ratio",
          href: "/docs/components/aspect-ratio",
          items: [],
        },
        {
          title: "Avatar",
          href: "/docs/components/avatar",
          items: [],
        },
        {
          title: "Badge",
          href: "/docs/components/badge",
          items: [],
        },
        {
          title: "Breadcrumb",
          href: "/docs/components/breadcrumb",
          items: [],
          label: "New",
        },
        {
          title: "Button",
          href: "/docs/components/button",
          items: [],
        },
        {
          title: "Calendar",
          href: "/docs/components/calendar",
          items: [],
        },
        {
          title: "Card",
          href: "/docs/components/card",
          items: [],
        },
        {
          title: "Carousel",
          href: "/docs/components/carousel",
          items: [],
        },
        {
          title: "Checkbox",
          href: "/docs/components/checkbox",
          items: [],
        },
        {
          title: "Collapsible",
          href: "/docs/components/collapsible",
          items: [],
        },
        {
          title: "Combobox",
          href: "/docs/components/combobox",
          items: [],
        },
        {
          title: "Command",
          href: "/docs/components/command",
          items: [],
        },
        {
          title: "Context Menu",
          href: "/docs/components/context-menu",
          items: [],
        },
        {
          title: "Data Table",
          href: "/docs/components/data-table",
          items: [],
        },
        {
          title: "Date Picker",
          href: "/docs/components/date-picker",
          items: [],
        },
        {
          title: "Dialog",
          href: "/docs/components/dialog",
          items: [],
        },
        {
          title: "Drawer",
          href: "/docs/components/drawer",
          items: [],
        },
        {
          title: "Dropdown Menu",
          href: "/docs/components/dropdown-menu",
          items: [],
        },
        {
          title: "Form",
          href: "/docs/components/form",
          items: [],
        },
        {
          title: "Hover Card",
          href: "/docs/components/hover-card",
          items: [],
        },
        {
          title: "Input",
          href: "/docs/components/input",
          items: [],
        },
        {
          title: "Input OTP",
          href: "/docs/components/input-otp",
          items: [],
          label: "New",
        },
        {
          title: "Label",
          href: "/docs/components/label",
          items: [],
        },
        {
          title: "Menubar",
          href: "/docs/components/menubar",
          items: [],
        },
        {
          title: "Navigation Menu",
          href: "/docs/components/navigation-menu",
          items: [],
        },
        {
          title: "Pagination",
          href: "/docs/components/pagination",
          items: [],
        },
        {
          title: "Popover",
          href: "/docs/components/popover",
          items: [],
        },
        {
          title: "Progress",
          href: "/docs/components/progress",
          items: [],
        },
        {
          title: "Radio Group",
          href: "/docs/components/radio-group",
          items: [],
        },
        {
          title: "Resizable",
          href: "/docs/components/resizable",
          items: [],
        },
        {
          title: "Scroll Area",
          href: "/docs/components/scroll-area",
          items: [],
        },
        {
          title: "Select",
          href: "/docs/components/select",
          items: [],
        },
        {
          title: "Separator",
          href: "/docs/components/separator",
          items: [],
        },
        {
          title: "Sheet",
          href: "/docs/components/sheet",
          items: [],
        },
        {
          title: "Skeleton",
          href: "/docs/components/skeleton",
          items: [],
        },
        {
          title: "Slider",
          href: "/docs/components/slider",
          items: [],
        },
        {
          title: "Sonner",
          href: "/docs/components/sonner",
          items: [],
        },
        {
          title: "Switch",
          href: "/docs/components/switch",
          items: [],
        },
        {
          title: "Table",
          href: "/docs/components/table",
          items: [],
        },
        {
          title: "Tabs",
          href: "/docs/components/tabs",
          items: [],
        },
        {
          title: "Textarea",
          href: "/docs/components/textarea",
          items: [],
        },
        {
          title: "Toast",
          href: "/docs/components/toast",
          items: [],
        },
        {
          title: "Toggle",
          href: "/docs/components/toggle",
          items: [],
        },
        {
          title: "Toggle Group",
          href: "/docs/components/toggle-group",
          items: [],
        },
        {
          title: "Tooltip",
          href: "/docs/components/tooltip",
          items: [],
        },
      ],
    },
  ],
};
